Learn R Programming

ssrn (version 0.1.0)

jreast_jt_od: JR-East Tokaido Line OD Data

Description

JR-East Tokaido Line OD Data

Arguments

Value

  • jreast_jt_od a tibble

Details

Census values made in 2015. The number of passengers between stations on the Tokaido Line. These values are those of commuter pass users.

  • departure_st_code: Departing station identification number.

  • arrive_st_code: The identification number of the station you are arriving at.

  • volume Number of people getting on and off the train.

See Also

https://www.mlit.go.jp/sogoseisaku/transport/sosei_transport_tk_000035.html